<?php

/**
 * Callback page for Orbital Hosted Payment Form.
 *
 * The payment iframe embeds this page within itself, so we cannot use the
 * regular checkout payment pages as callbacks.
 *
 * @param $order
 *
 * @return int|string
 */
function commerce_chase_orbital_hpf_callback($order) {
  // If the user does not have access to checkout the order, return a 404. We
  // could return a 403, but then the user would know they've identified a
  // potentially valid checkout URL.
  if (!commerce_checkout_access($order) || arg(4) != $order->data['payment_redirect_key']) {
    return MENU_ACCESS_DENIED;
  }

  $frame_url_parameters = array(
    'errorCode' => (isset($_GET['errorCode'])) ? filter_xss($_GET['errorCode']) : NULL,
    'cancel' => (isset($_GET['cancel'])) ? filter_xss($_GET['cancel']) : NULL,
    'whatCVV2' => (isset($_GET['whatCVV2'])) ? filter_xss($_GET['whatCVV2']) : NULL,
    'whatsThis' => (isset($_GET['whatsThis'])) ? filter_xss($_GET['whatsThis']) : NULL,
    'gatewayCode' => (isset($_GET['gatewayCode'])) ? filter_xss($_GET['gatewayCode']) : NULL,
    'gatewayMessage' => (isset($_GET['gatewayMessage'])) ? filter_xss($_GET['gatewayMessage']) : NULL,
    'currentLocation' => (isset($_GET['rurl'])) ? filter_xss($_GET['rurl']) : NULL,
    'action' => (isset($_GET['action'])) ? filter_xss($_GET['action']) : NULL,
    'processStart' => (isset($_GET['processStart'])) ? filter_xss($_GET['processStart']) : NULL,
    'cancelUrl' => url('checkout/' . $order->order_id . '/payment/back/' . $order->data['payment_redirect_key'], array('absolute' => TRUE)),
    'returnUrl' => url('checkout/' . $order->order_id . '/payment/return/' . $order->data['payment_redirect_key'], array('absolute' => TRUE)),
  );

  drupal_add_js(array('chaseOrbitalHpf' => $frame_url_parameters), 'setting');
  drupal_add_js(drupal_get_path('module', 'commerce_chase_orbital_hpf') . '/commerce-chase-orbital-hpf.js');

  return '<iframe id="loadingCompleteFrame" style="display: none;position: absolute;height: 1px;width: 1px;top: 1px;left: 1px;"></iframe>';
}
